@@ -1,5 +1,5 @@
 #![warn(clippy::pedantic)]
-#![allow(clippy::unreadable_literal)]
+#![allow(clippy::unreadable_literal, clippy::double_must_use)]
 
 pub mod analysis;
 pub mod games;
